# My Rest Engine

Please refer to [Readme](https://github.com/xiaoyexu/myrestengine/blob/master/README-EN.md) or [中文文档](https://github.com/xiaoyexu/myrestengine/blob/master/README-CN.md)

## Latest Release 0.1.6

- Added `afterGetList` `afterGetSingle`  `afterPost` `afterPut` `afterDelete` methods in Processor

## Release 0.1.5

- Allow None in _query expression, e.g. ?_query=name=None

## Release 0.1.4

- Addded start method on engine object

## Release 0.1.3

- Added parameter `_columns` to return columns listed

## Release 0.1.2

- Added setLogger in engine

## Release 0.1.1 (Removed from pypi.org)

- Added new annotation usage
- Added configure name in settings.py


## Release 0.1.0 (Removed from pypi.org)

- Initialize project